# Generated by Django 5.1 on 2024-10-20 15:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0020_customer_document_check_digit'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='trade_name',
            field=models.CharField(blank=True, help_text='Commertial Name of the customer.', max_length=100, null=True, verbose_name='Commertial Name'),
        ),
    ]
