# Generated by Django 5.1 on 2025-03-25 02:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0021_customer_trade_name"),
    ]

    operations = [
        migrations.AlterField(
            model_name="customer",
            name="trade_name",
            field=models.CharField(
                blank=True,
                help_text="Trade name of the customer.",
                max_length=100,
                null=True,
                verbose_name="Trade name",
            ),
        ),
    ]
