# Generated by Django 5.1 on 2025-04-08 02:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_customer", "0023_customerimportresult"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="customerimportresult",
            name="file",
        ),
        migrations.AddField(
            model_name="customerimportresult",
            name="file_name",
            field=models.CharField(
                blank=True,
                help_text="File name",
                max_length=250,
                null=True,
                verbose_name="File name",
            ),
        ),
    ]
